pub fn load_config(config_path: &Path) -> Result<CheckConfig>Expand description
Load check config from a TOML file path. Falls back to defaults if the file is missing.
pub fn load_config(config_path: &Path) -> Result<CheckConfig>Load check config from a TOML file path. Falls back to defaults if the file is missing.