pub fn run_checks(
root: &Path,
config: &CheckConfig,
store: &GraphStore,
selection: &CheckSelection,
) -> Vec<CheckResult>Expand description
Run the selected checks against a project root and return results.
pub fn run_checks(
root: &Path,
config: &CheckConfig,
store: &GraphStore,
selection: &CheckSelection,
) -> Vec<CheckResult>Run the selected checks against a project root and return results.