pub fn extract_file(
path: &str,
source: &[u8],
pack: &LanguagePack,
) -> Result<FileExtraction>Expand description
Parse a source file and extract all symbols and relationships.
pub fn extract_file(
path: &str,
source: &[u8],
pack: &LanguagePack,
) -> Result<FileExtraction>Parse a source file and extract all symbols and relationships.